@@ -1,7 +1,7 @@
 import shutil
 import platform
 import socket
-from os.path import exists
+from os.path import exists, abspath
 
 
 def fix_path_for_docker(path):
@@ -20,3 +20,7 @@ def copy_folder(source_path, destination_path, remove_destination=False):
 def is_port_in_use(port):
     with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
         return s.connect_ex(('localhost', port)) == 0
+
+
+def is_openml_dataset(url):
+    return url.startswith('https://www.openml.org/')
